=== modified file '.bzrignore'
--- .bzrignore	2013-06-11 12:14:36 +0000
+++ .bzrignore	2013-06-11 16:05:35 +0000
@@ -11,6 +11,5 @@
 Testing/
 *.cbp
 po/*.gmo
-
-
+*.desktop
 

=== modified file 'CMakeLists.txt'
--- CMakeLists.txt	2013-06-11 12:14:00 +0000
+++ CMakeLists.txt	2013-06-11 16:05:35 +0000
@@ -71,11 +71,29 @@
     DESTINATION ${CAMERA_APP_DIR}
     )
 
-install(FILES ${CAMERA_APP}.desktop
+set(DESKTOP_FILE camera-app.desktop)
+file(REMOVE ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE})
+file(STRINGS ${DESKTOP_FILE}.in DESKTOP_FILE_CONTENTS)
+foreach(LINE ${DESKTOP_FILE_CONTENTS})
+    string(REGEX REPLACE "tr\\\(\"(.*)\"\\\)" "\\1" LINE "${LINE}")
+    file(APPEND ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE} "${LINE}\n")
+endforeach(LINE)
+
+install(FILES ${CMAKE_CURRENT_BINARY_DIR}/${DESKTOP_FILE}
     DESTINATION ${CMAKE_INSTALL_DATADIR}/applications
     )
 
 add_subdirectory(CameraApp)
+
+file(GLOB_RECURSE I18N_SRC_FILES
+     RELATIVE ${CMAKE_CURRENT_SOURCE_DIR}
+     **.qml **.desktop.in)
+list(SORT I18N_SRC_FILES)
+
+# for dh_translations to extract the domain
+# (regarding syntax consistency, see http://pad.lv/1181187)
+set (GETTEXT_PACKAGE "camera-app")
+
 add_subdirectory(po)
 
 enable_testing()

=== renamed file 'camera-app.desktop' => 'camera-app.desktop.in'
--- camera-app.desktop	2013-06-11 12:14:00 +0000
+++ camera-app.desktop.in	2013-06-11 16:05:35 +0000
@@ -1,8 +1,8 @@
 [Desktop Entry]
 Type=Application
-Name=Camera
+Name=tr("Camera")
 GenericName=camera-app
-Comment=Camera application
+Comment=tr("Camera application")
 Exec=camera-app --fullscreen %u
 Terminal=false
 Icon=camera-app

=== modified file 'debian/control'
--- debian/control	2013-06-11 12:14:00 +0000
+++ debian/control	2013-06-11 16:05:35 +0000
@@ -16,6 +16,7 @@
                qtdeclarative5-ubuntu-ui-toolkit-plugin,
                qtmultimedia5-dev,
                gettext,
+               dh-translations,
 Standards-Version: 3.9.4
 Homepage: https://launchpad.net/camera-app
 # If you aren't a member of ~phablet-team but need to upload packaging changes,

=== modified file 'debian/rules'
--- debian/rules	2013-03-16 05:00:40 +0000
+++ debian/rules	2013-06-11 16:05:35 +0000
@@ -6,7 +6,13 @@
 export DPKG_GENSYMBOLS_CHECK_LEVEL=4
 
 %:
-	dh $@ --parallel
+	dh $@ --parallel --with translations
 
 override_dh_install:
 	dh_install --fail-missing
+
+override_dh_translations:
+	# Override dh_translations to work around http://pad.lv/1183262.
+	# Unfortunately, the default build directory is not exposed
+	# (see http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=601774).
+	$(MAKE) -C obj-$(DEB_HOST_GNU_TYPE) camera-app.pot

=== modified file 'po/CMakeLists.txt'
--- po/CMakeLists.txt	2013-06-11 12:14:00 +0000
+++ po/CMakeLists.txt	2013-06-11 16:05:35 +0000
@@ -1,11 +1,22 @@
 project(camera-app-translations)
 
 include(FindGettext)
+find_program(GETTEXT_XGETTEXT_EXECUTABLE xgettext)
 
-set(DOMAIN camera-app)
+set(DOMAIN ${GETTEXT_PACKAGE})
 set(POT_FILE ${DOMAIN}.pot)
 file(GLOB PO_FILES *.po)
 
+add_custom_target(${POT_FILE}
+                  COMMAND ${GETTEXT_XGETTEXT_EXECUTABLE} -o ${POT_FILE}
+                          -D ${CMAKE_SOURCE_DIR}
+                          --from-code=UTF-8
+                          --c++ --qt --add-comments=TRANSLATORS
+                          --keyword=tr --keyword=tr:1,2
+                          --package-name=camera-app
+                          --copyright-holder='Canonical Ltd.'
+                          ${I18N_SRC_FILES})
+
 foreach(PO_FILE ${PO_FILES})
     get_filename_component(LANG ${PO_FILE} NAME_WE)
     gettext_process_po_files(${LANG} ALL PO_FILES ${PO_FILE})

=== modified file 'po/camera-app.pot'
--- po/camera-app.pot	2013-06-11 12:14:00 +0000
+++ po/camera-app.pot	2013-06-11 16:05:35 +0000
@@ -16,6 +16,14 @@
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: 8bit\n"
 
+#: camera-app.desktop.in:3
+msgid "Camera"
+msgstr ""
+
+#: camera-app.desktop.in:5
+msgid "Camera application"
+msgstr ""
+
 #: camera-app.qml:38
 msgid "Flash"
 msgstr ""

=== modified file 'po/it.po'
--- po/it.po	2013-06-11 12:14:00 +0000
+++ po/it.po	2013-06-11 16:05:35 +0000
@@ -18,6 +18,14 @@
 "X-Generator: Launchpad (build 16660)\n"
 "Language: it\n"
 
+#: camera-app.desktop.in:3
+msgid "Camera"
+msgstr "Macchina Fotografica"
+
+#: camera-app.desktop.in:5
+msgid "Camera application"
+msgstr "Applicazione per Foto e Video"
+
 #: camera-app.qml:38
 msgid "Flash"
 msgstr "Flash"

